#!/bin/bash
#
# This script strips out text from overall_results files generated by 
# TestWildTypeMonoclonality.hpp and prints the relevant numbers to collated 
# results files.
#
# Last updated 13/10/09


if cd processed; then
    rm -f processed_results_WT.dat
else
    mkdir processed
fi
cd ..

INPUTFILENAME=overall_results_WT.dat

# If this file exists...
if [ -e $INPUTFILENAME ]; then
	echo "Processing $INPUTFILENAME..."

	OUTPUTFILENAME=processed/processed_results_WT.dat

	# The first line of the collated results file is the experiment number (to ignore)
	# The second line is the ancestor height
	# The third line is the monoclonality time (rounded to nearest hour)
	# The fourth line is the time that the initial ancestor left the crypt.

	# All this info in the filename
	#awk '{if (NR==2 || NR==3 || NR==4) print $NF}' $INPUTFILENAME > $OUTPUTFILENAME

	# Print the result of each experiment to a temporary file
	awk '{if (NR%4==2 || NR%4==3 || NR%4==0 ) print}' $INPUTFILENAME > tempfile.dat

	# Strip out the text so matlab can load the file easily. The result of each 
	# experiment is either 0 (corresponding to the mutant population being washed 
	# out of the crypt), 1 (corresponding to the mutant population taking over 
	# the crypt) or 2 (corresponding to there being no result in the allotted time)
	awk '{gsub(/EXPERIMENT = /,""); gsub(/Ancestor height = /,""); gsub(/Monoclonality time by = /,""); gsub(/Cells lost time by = /,""); gsub(/EXPERIMENTS COMPLETE/,""); print}' tempfile.dat >> $OUTPUTFILENAME

	# Tidy up
	rm -f tempfile.dat

	echo "done."
else
	echo "File $INPUTFILENAME doesn't exist."
fi

