#!/bin/bash
#
# This script strips out text from overall_results files generated by 
# TestCryptInvasion.hpp and prints the relevant numbers to collated 
# results files.
#
# Last updated 17/03/10

# Here are all possible parameters...

MUTANT_PROLIFERATION_HEIGHT[0]="0.3"
MUTANT_PROLIFERATION_HEIGHT[1]="0.4"
MUTANT_PROLIFERATION_HEIGHT[2]="0.5"
MUTANT_PROLIFERATION_HEIGHT[3]="0.6"
MUTANT_PROLIFERATION_HEIGHT[4]="0.7"
MUTANT_PROLIFERATION_HEIGHT[5]="0.8"
MUTANT_PROLIFERATION_HEIGHT[6]="0.9"
MUTANT_PROLIFERATION_HEIGHT[7]="1.0"

for (( i=0 ; i<${#MUTANT_PROLIFERATION_HEIGHT[*]} ; i++))
do
	INPUTFILENAME=proliferation_only_overall_results${MUTANT_PROLIFERATION_HEIGHT[$i]}.dat

	# If this file exists...
	if [ -e $INPUTFILENAME ]; then
		echo "Processing $INPUTFILENAME..."

		OUTPUTFILENAME=processed/processed_results_proliferation_only${MUTANT_PROLIFERATION_HEIGHT[$i]}.dat

		# Print the experiment number, height, duration and result of each experiment to a temporary file
		awk '{if (NR%11==1 || NR%11==2 || NR%11==6 || NR%11==7 || NR%11==8 || NR%11==9 || NR%11==10 ||NR%11==0) print}' $INPUTFILENAME > tempfile.dat

		# Strip out the text so matlab can load the file easily. The result of each 
		# experiment is either 0 (corresponding to the mutant population being washed 
		# out of the crypt), 1 (corresponding to the mutant population taking over 
		# the crypt) or 2 (corresponding to there being no result in the allotted time)
		awk '{gsub(/EXPERIMENT = /,""); gsub(/Initial mutation height = /,""); gsub(/Initial mutation proliferation ceiling height fraction = /,""); gsub(/Experiment duration = /,""); gsub(/Time averaged = /,""); gsub(/Average force on WT = /,"");  gsub(/Average force on mutant = /,""); gsub(/Number of cells in crypt at end = /,"");  gsub(/Mutant population washed out of crypt/,0); gsub(/Mutant population taken over crypt/,1); gsub(/No result/,-1); gsub(/EXPERIMENTS COMPLETE/,""); print}' tempfile.dat >> $OUTPUTFILENAME

		# Tidy up
		rm -f tempfile.dat

		echo "done."
	else
		echo "File $INPUTFILENAME doesn't exist."
	fi
done
